==> vokoscreen_2.0.5~beta.orig.tar.gz: vokoscreen-2.0.5-beta/language/vokoscreen_sv_SE.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sv_SE" version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation>Mejla sensaste video</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Mejla en eller flera valda video</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Skicka</translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Du hittar videon som bilaga</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Välj en eller flera filer</translation>
    </message>
</context>
<context>
    <name>QvkWebcam</name>
    <message>
        <source>Noborder</source>
        <translation>Ingen ram</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Ram</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
</context>
<context>
    <name>QvkWebcamController</name>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Device is busy</source>
        <translation>Enheten är upptagen</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Fullskärm</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Fönster</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Område</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Förstoringsglas</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Ljud</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Spela inte in muspekaren</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videosökväg</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Spelare</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen är förminskad när inspelningen startas</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Starta</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Spela</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Skicka</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Inspelningstid</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Storlek in kb</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Inspelning skärmstorlek</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Inställningar fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Öppen katalog</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Nedräkning</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Spela förra videon</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Skicka video</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Mejla en eller flera valda video</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Aktuella antal bilder per sekund</translation>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation>Device %1 är upptagen</translation>
    </message>
    <message>
        <source>Your Actual frames in the Settings is too heigh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Go</source>
        <translation>Starta</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Frames</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Donate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Program for recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.0.16~beta.orig.tar.gz: vokoscreen-2.0.16-beta/language/vokoscreen_sv_SE.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sv_SE" version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation>Mejla sensaste video</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Mejla en eller flera valda video</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Skicka</translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Du hittar videon som bilaga</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Välj en eller flera filer</translation>
    </message>
</context>
<context>
    <name>QvkWebcamController</name>
    <message>
        <source>is busy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Noborder</source>
        <translation>Ingen ram</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Ram</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Fullskärm</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Fönster</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Område</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Förstoringsglas</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Ljud</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Spela inte in muspekaren</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videosökväg</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Spelare</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen är förminskad när inspelningen startas</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Starta</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Spela</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Skicka</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Inspelningstid</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Storlek in kb</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Inspelning skärmstorlek</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Inställningar fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Öppen katalog</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Nedräkning</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Spela förra videon</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Skicka video</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Mejla en eller flera valda video</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Aktuella antal bilder per sekund</translation>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation>Device %1 är upptagen</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Starta</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Frames</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Donate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Program for recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
